\name{addDerivedCategorical}
\alias{addDerivedCategorical}
\title{Add binned variable to NONMEM object}
\usage{addDerivedCategorical(obj, varName, newVar=paste(varName, ".CUT", sep = ""), 
breaks=5, binType="range", labels, ...)}
\description{This function allows the user to create new variables derived from actual input or output data stored in a NONMEM object or a data.frame.
The function "bins" the data in a user-chosen manner.  The new "binned" variable will be added to the "additionalVars" data frame of the object, or as a new column if the 
object is a data.frame. The methods for creating the categorical variables are:
\itemize{
\item{unique:}{Variable is coerced into a factor with no "binning" at all}
\item{explicitcuts:}{The user supplies "cut points" for partitioning the data}
\item{range:}{The user specifies a number of cut points, and they are the generated by cutting the range of the values of the variable into the given number}
\item{logrange:}{As above, but done by range of the log of the variable}
\item{counts:}{User specifies number of cut points, and the bins are then generated so that the bins have equal amounts of data}
}}
\note{If the \code{binType} is \code{counts} and calculation of quantiles generates duplicates, a warning will be eliminated and the duplicates
will be discarded.}
\value{A new object with a user-specified "binned" variable added}
\keyword{datagen}
\author{Mango Solutions}
\arguments{\item{obj}{An object of class NMBasicModel, NMRun, NMSimModel, NMSimDataGen or data.frame}
\item{varName}{The variable to "bin"}
\item{newVar}{The name of the new variable}
\item{breaks}{The number of breaks}
\item{binType}{The type of "binning"}
\item{labels}{The labels for the "bins"}
\item{...}{Additional arguments that apply to different classes. These are dataType which specifies what data to use, i.e input or 
output, for NMBasicModel, NMRun, NMSimModel and NMSimDataGen, and problemNum which specifies the required run for an NMRun object}
}
\examples{x <- addDerivedCategorical(mtcars, "mpg", breaks = 6, binType = "counts" )
show(x$mpg.CUT)}

